package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcSafeReport;

/**
 * 安全汇报Mapper接口
 * 
 * @author cmc
 * @date 2024-06-24
 */
public interface CmcSafeReportMapper 
{
    /**
     * 查询安全汇报
     * 
     * @param safeReportId 安全汇报主键
     * @return 安全汇报
     */
    public CmcSafeReport selectCmcSafeReportBySafeReportId(Integer safeReportId);

    /**
     * 查询安全汇报列表
     * 
     * @param cmcSafeReport 安全汇报
     * @return 安全汇报集合
     */
    public List<CmcSafeReport> selectCmcSafeReportList(CmcSafeReport cmcSafeReport);

    /**
     * 新增安全汇报
     * 
     * @param cmcSafeReport 安全汇报
     * @return 结果
     */
    public int insertCmcSafeReport(CmcSafeReport cmcSafeReport);

    /**
     * 修改安全汇报
     * 
     * @param cmcSafeReport 安全汇报
     * @return 结果
     */
    public int updateCmcSafeReport(CmcSafeReport cmcSafeReport);

    /**
     * 删除安全汇报
     * 
     * @param safeReportId 安全汇报主键
     * @return 结果
     */
    public int deleteCmcSafeReportBySafeReportId(Integer safeReportId);

    /**
     * 批量删除安全汇报
     * 
     * @param safeReportIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcSafeReportBySafeReportIds(Integer[] safeReportIds);
}
